@@ -25,9 +25,9 @@
  *
  * $Log: asner.cxx,v $
  * Revision 1.93  2005/11/30 12:47:41  csoutheren
- * $Revision: 20385 $
+ * $Revision: 23918 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 05:40:38 -0500 (Wed, 04 Jun 2008) $
+ * $Date: 2010-01-10 22:03:52 -0600 (Sun, 10 Jan 2010) $
  */
 
 #include <ptlib.h>
@@ -978,7 +978,7 @@ PObject * PASN_BitString::Clone() const
 
 void PASN_BitString::PrintOn(ostream & strm) const
 {
-  int indent = strm.precision() + 2;
+  int indent = (int)strm.precision() + 2;
   ios::fmtflags flags = strm.flags();
 
   if (totalBits > 128)
@@ -1139,7 +1139,7 @@ PObject * PASN_OctetString::Clone() const
 
 void PASN_OctetString::PrintOn(ostream & strm) const
 {
-  int indent = strm.precision() + 2;
+  int indent = (int)strm.precision() + 2;
   ios::fmtflags flags = strm.flags();
 
   strm << ' ' << value.GetSize() << " octets {\n"
@@ -1498,15 +1498,8 @@ PBoolean PASN_BMPString::IsLegalCharacter(WORD ch)
   return PFalse;
 }
 
-
-PASN_BMPString & PASN_BMPString::operator=(const PWCharArray & array)
+void PASN_BMPString::SetValueRaw(const wchar_t * array, PINDEX paramSize)
 {
-  PINDEX paramSize = array.GetSize();
-
-  // Remove trailing NULL character, if present
-  if (paramSize > 0 && array[paramSize-1] == 0)
-    paramSize--;
-
   // Can't copy any more than the upper constraint
   if ((unsigned)paramSize > upperLimit)
     paramSize = upperLimit;
@@ -1526,6 +1519,18 @@ PASN_BMPString & PASN_BMPString::operator=(const PWCharArray & array)
   while (count < newSize)
     value[count++] = firstChar;
 
+}
+
+PASN_BMPString & PASN_BMPString::operator=(const PWCharArray & array)
+{
+  PINDEX paramSize = array.GetSize();
+
+  // Remove trailing NULL character, if present
+  if (paramSize > 0 && array[paramSize-1] == 0)
+    paramSize--;
+
+  SetValueRaw(array, paramSize);
+ 
   return *this;
 }
 
@@ -1601,7 +1606,7 @@ PObject::Comparison PASN_BMPString::Compare(const PObject & obj) const
 
 void PASN_BMPString::PrintOn(ostream & strm) const
 {
-  int indent = strm.precision() + 2;
+  int indent = (int)strm.precision() + 2;
   PINDEX sz = value.GetSize();
   strm << ' ' << sz << " characters {\n";
   PINDEX i = 0;
@@ -2078,7 +2083,7 @@ PObject * PASN_Sequence::Clone() const
 
 void PASN_Sequence::PrintOn(ostream & strm) const
 {
-  int indent = strm.precision() + 2;
+  int indent = (int)strm.precision() + 2;
   strm << "{\n";
   for (PINDEX i = 0; i < fields.GetSize(); i++) {
     strm << setw(indent+6) << "field[" << i << "] <";
@@ -2256,7 +2261,7 @@ PObject::Comparison PASN_Array::Compare(const PObject & obj) const
 
 void PASN_Array::PrintOn(ostream & strm) const
 {
-  int indent = strm.precision() + 2;
+  int indent = (int)strm.precision() + 2;
   strm << array.GetSize() << " entries {\n";
   for (PINDEX i = 0; i < array.GetSize(); i++)
     strm << setw(indent+1) << "[" << i << "]=" << setprecision(indent) << array[i] << '\n';
@@ -2343,7 +2348,7 @@ void PASN_Stream::Construct()
 
 void PASN_Stream::PrintOn(ostream & strm) const
 {
-  int indent = strm.precision() + 2;
+  int indent = (int)strm.precision() + 2;
   strm << " size=" << GetSize()
        << " pos=" << byteOffset << '.' << (8-bitOffset)
        << " {\n";
