@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 23336 $
+ * $Revision: 24875 $
  * $Author: rjongbloed $
- * $Date: 2009-09-04 20:02:14 -0500 (Fri, 04 Sep 2009) $
+ * $Date: 2010-11-12 02:03:15 -0600 (Fri, 12 Nov 2010) $
  */
 
 #ifdef __GNUC__
@@ -48,7 +48,8 @@ extern "C" {
 };
 
 #ifdef _MSC_VER
-#pragma comment(lib, P_SDL_LIBRARY)
+  #pragma comment(lib, P_SDL_LIBRARY)
+  #pragma message("SDL video support enabled")
 #endif
 
 
@@ -215,10 +216,10 @@ bool PVideoOutputDevice_SDL::InitialiseSDL()
   ::SDL_WM_SetCaption(title, NULL);
 
   pos = deviceName.Find("X=");
-  int x = pos != P_MAX_INDEX ? atoi(&deviceName[pos+2]) : 0;
+  int x = pos != P_MAX_INDEX ? atoi(&deviceName[pos+2]) : 100;
 
   pos = deviceName.Find("Y=");
-  int y = pos != P_MAX_INDEX ? atoi(&deviceName[pos+2]) : 0;
+  int y = pos != P_MAX_INDEX ? atoi(&deviceName[pos+2]) : 100;
 
   PString winpos(PString::Printf, "SDL_VIDEO_WINDOW_POS=%i,%i", x, y);
   putenv(winpos.GetPointer());
@@ -242,7 +243,7 @@ bool PVideoOutputDevice_SDL::InitialiseSDL()
 bool PVideoOutputDevice_SDL::ProcessSDLEvents()
 {
   if (screen == NULL || overlay == NULL) {
-    PTRACE(6, "VSDL\t Screen and/or overlay not open, so dont process events");
+    PTRACE(6, "VSDL\t Screen and/or overlay not open, so don't process events");
     return false;
   }
 
@@ -318,6 +319,12 @@ void PVideoOutputDevice_SDL::SDLThreadMain(PThread &, INT)
 }
 
 
+#else
+
+  #ifdef _MSC_VER
+    #pragma message("SDL video support DISABLED")
+  #endif
+
 #endif // P_SDL
 
 
