@@ -7,9 +7,9 @@
  *
  * Contributor(s): Snark at GnomeMeeting
  *
- * $Revision: 22015 $
- * $Author: rjongbloed $
- * $Date: 2009-02-06 19:15:01 -0600 (Fri, 06 Feb 2009) $
+ * $Revision: 25955 $
+ * $Author: ededu $
+ * $Date: 2011-06-01 09:02:07 -0500 (Wed, 01 Jun 2011) $
  */
 
 #include <ptlib.h>
@@ -111,11 +111,13 @@ void PPluginManager::LoadPluginDirectory (const PDirectory & directory, const PS
   } while (dir.Next());
 }
 
+
 void PPluginManager::AddPluginDirs(PString dirs)
 {
-  additionalPluginDirs = PATH_SEP + dirs;
+  additionalPluginDirs += PATH_SEP + dirs;
 }
 
+
 PStringArray PPluginManager::GetPluginDirs()
 {
   PString env = ::getenv(ENV_PTLIB_PLUGIN_DIR);
@@ -148,7 +150,7 @@ PBoolean PPluginManager::LoadPlugin(const PString & fileName)
 
   PDynaLink *dll = new PDynaLink(fileName);
   if (!dll->IsLoaded()) {
-    PTRACE(4, "PLUGIN\tFailed to open " << fileName);
+    PTRACE(4, "PLUGIN\tFailed to open " << fileName << " error: " << dll->GetLastError());
   }
 
   else {
@@ -507,8 +509,5 @@ void PluginLoaderStartup::OnShutdown()
   }
 }
 
-static PFactory<PProcessStartup>::Worker<PluginLoaderStartup> pluginLoaderStartupFactory("PluginLoader", true);
-
-PINSTANTIATE_FACTORY(PluginLoaderStartup, PString)
-
+PFACTORY_CREATE(PFactory<PProcessStartup>, PluginLoaderStartup, "PluginLoader", true);
 
