@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22963 $
+ * $Revision: 25251 $
  * $Author: rjongbloed $
- * $Date: 2009-06-23 21:20:32 -0500 (Tue, 23 Jun 2009) $
+ * $Date: 2011-03-04 05:12:05 -0600 (Fri, 04 Mar 2011) $
  */
 
 #define _OSUTIL_CXX
@@ -65,6 +65,7 @@
 #else
 #include <time.h>
 #include <sys/time.h>
+#include <termios.h>
 #endif
 #include <ctype.h>
 
@@ -84,6 +85,7 @@
 
 #include <sys/param.h>
 #include <sys/mount.h>
+#include <sys/timeb.h>
 
 #if defined(P_NETBSD)
 #include <sys/statvfs.h>
@@ -98,7 +100,6 @@
 
 #include <fstab.h>
 #include <sys/stat.h>
-#include <sys/statfs.h>
 
 #elif defined(P_SOLARIS) 
 #define P_USE_LANGINFO
@@ -303,7 +304,7 @@ PUInt64 PString::AsUnsigned64(unsigned base) const
 
 PTimeInterval PTimer::Tick()
 {
-#ifdef _POSIX_MONOTONIC_CLOCK
+#if defined(_POSIX_MONOTONIC_CLOCK) && !defined(P_MACOSX)
   struct timespec ts;
   clock_gettime(CLOCK_MONOTONIC, &ts);
   return ts.tv_sec*1000LL + ts.tv_nsec/1000000LL;
@@ -1156,12 +1157,34 @@ PBoolean PConsoleChannel::Close()
 }
 
 
+bool PConsoleChannel::SetLocalEcho(bool localEcho)
+{
+  if (!IsOpen())
+    return ConvertOSError(-2, LastReadError);
+
+#ifdef P_VXWORKS
+  PAssertAlways("PConsoleChannel::GetName - Not implemented for VxWorks");
+  return PString("Not Implemented");
+#else
+  struct termios ios;
+  if (!ConvertOSError(tcgetattr(os_handle, &ios)))
+    return false;
+
+  if (localEcho)
+    ios.c_lflag |= ECHO;
+  else
+    ios.c_lflag &= ~ECHO;
+  return ConvertOSError(tcsetattr(os_handle, TCSANOW, &ios));
+#endif
+}
+
+
 //////////////////////////////////////////////////////
 //
 //  PTime
 //
 
-PTime::PTime()
+void PTime::SetCurrentTime()
 {
 #ifdef P_VXWORKS
   struct timespec ts;
